// KreateCD - CD recording software for the K desktop environment
//
// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General
// Public License.  See the file COPYING in the main directory of the
// KreateCD distribution for more details.

#include <qobject.h>
#include <kprocess.h>

class AudioFileOp;

class Fork : public KProcess
 {
  Q_OBJECT;

  public:
  Fork(int (*fx)(int argc,char **argv));
  Fork(int (*fx)(AudioFileOp *afi,const char *fn),AudioFileOp *afil,const char *fnx);

  bool start(RunMode, Communication);
  
  bool writeStdIn(char *buffer,int bufflen);

  private:
  int (*function)(int argc,char **argv);

  int (*function_af1)(AudioFileOp *afi,const char *fn);


  int fmode;
  AudioFileOp *AFile;


  char strarg[1024];

 };
